#
# spec file for package ncmpcpp
#
# Copyright (c) 2016 Packman Team <packman@links2linux.de>
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#


Name:           ncmpcpp
Version:        0.7.7
Release:        2.1
Summary:        Music Player Daemon Client
License:        GPL-2.0
Group:          Productivity/Multimedia/Sound/Players
Url:            https://rybczak.net/ncmpcpp
Source:         https://github.com/arybczak/ncmpcpp/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  boost-devel >= 1.54
BuildRequires:  curl-devel
BuildRequires:  fftw-devel
BuildRequires:  gcc-c++
BuildRequires:  libmpdclient-devel
BuildRequires:  libtag-devel
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
Requires:       mpd > 0.16
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Ncmpcpp is almost exact clone of ncmpc but it contains some new features ncmpc doesn't have.
It's been also rewritten from scratch in C++. Lack of some function (eg. tag editor)
eventually pushed me to rewrite it as ncmpcpp and include these functions in it.

%prep
%setup -q

%build
./autogen.sh
%configure --enable-clock --enable-visualizer
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
rm -rf "%{buildroot}%{_datadir}/doc"

%files
%defattr(-,root,root)
%doc AUTHORS COPYING NEWS doc/config doc/bindings
%{_bindir}/ncmpcpp
%doc %{_mandir}/man1/ncmpcpp.1%{ext_man}

%changelog
* Wed Dec 14 2016 aloisio@gmx.com
- Update to version 0.7.7
  * Fixed compilation on 32bit platforms.
  ncmpcpp-0.7.6 (2016-10-30)
  * Fixed assertion failure on trying to search backwards in
    an empty list.
  * Updated installation instructions in INSTALL file.
  * Make sure that stream of random numbers is not
    deterministic.
  * Opening playlist editor when there is no MPD playlists
    directory no longer freezes the application.
  * Added info about behavior of MPD_HOST and MPD_PORT
    environment variables to man page.
  * Tilde will now be expanded to home directory in
    visualizer_fifo_path, execute_on_song_change and
    external_editor configuration variables.
  * Fixed lyricwiki and justsomelyrics fetchers.
  ncmpcpp-0.7.5 (2016-08-17)
  * Action chains can be now used for seeking.
  * Fixed fetching artist info from last.fm.
  * Default value of regular_expressions was changed from
    'basic' to 'perl' to work around boost issue (#12222).
  * Fixed crash occuring when searching backward in an empty
    list.
  ncmpcpp 0.7.4 (2016-04-17)
  * Fetching lyrics from lyricwiki.org was fixed.
  * Configure script now continues without errors if ICU
    library was not found.
  ncmpcpp 0.7.3 (2016-01-20)
  * Home and End keys are now recognized in a few specific
    terminal emulators.
  ncmpcpp-0.7.2 (2016-01-16)
  * Attempt to add non-song item to playlist from search
    engine doesn't trigger assertion failure anymore.
  * Fetching lyrics from metrolyrics.com was fixed.
  * Alternative UI separator color is now respected regardless
    of the header_visibility flag.
  ncmpcpp-0.7.1 (2016-01-01)
  * Selected songs in media library can now be added to
    playlists.
  * Confirmation before shuffling a playlist can now be
    disabled.
  ncmpcpp-0.7 (2015-11-22)
  * Playlist sorting dialog now contains 'Album artist' option.
  * Default keybindings were corrected to allow tag edition in
    the right column of tag editor.
  * Mouse is properly kept disabled if it was disabled in the
    configuration file.
  ncmpcpp-0.6.8 (2015-11-11)
  * Application is now compatible with MPD >= 0.20.
  * Check for readline library was fixed.
  ncmpcpp-0.7_beta1 (2015-11-04)
  * Visualizer has now support for multiple colors
    (visualizer_color configuration variable takes the list of
    colors to be used).
  * Visualizer has now support for two more modes: sound wave
    filled and sound ellipse.
  * Visualizer's spectrum mode now scales better along with
    window's width.
  * It is now possible to abort the current action using
    Ctrl-C or Ctrl-G in prompt mode. As a result, empty value is
    no longer a special value that aborts most of the actions.
  * Directories and playlists in browser can now be sorted by
    modification time.
  * ~ is now expanded to home directory in mpd_host
    configuration variable.
  * It is now possible to define startup slave screen using
  - S/--slave-screen command line option or
    startup_slave_screen configuration variable.
  * List filtering has been removed due to the major part of
    its functionality overlapping with find forward/backward and
    obscure bugs.
  * Find backward/forward function is now incremental.
  * Support for 256 colors and customization of background
    colors has been added.
  * Multiple configuration files via command line arguments
    are now accepted. In addition, by default ncmpcpp attempts
    to read both $HOME/.ncmpcpp/config and
    $XDG_CONFIG_HOME/ncmpcpp/config (in this order).
  * Support for PDCurses has been removed due to the library
    being unmaintained and buggy.
  * Current MPD host may now be shown in playlist
    (playlist_show_mpd_host configuration variable, disabled by
    default).
  * Random album artists can now be added to the playlist.
  * Case insensitive searching is now Unicode aware as long as
    boost was compiled with ICU support.
  * Searching with regular expressions is now enabled by
    default.
  * Support for the Perl regular expression syntax was added.
  * BOOST_LIB_SUFFIX configure variable is now empty by
    default.
  * Shuffle function now shuffles only selected range if
    selection in playlist is active.
  * NCurses terminal sequence escaping is no longer used as
    it's not accurate enough.
  * Selecting items no longer depends on space mode and is
    bound by default to Insert key.
  * Support for Alt, Ctrl and Shift modifiers as well as
    Escape key was added.
  * Action that updates the environment can now be used in
    bindings configuration file.
  * Monolithic 'press_space' action was split into
    'add_item_to_playlist',
    'toggle_lyrics_update_on_song_change' and
    'toggle_visualization_type'.
  * Monolithic 'press_enter' action was split into
    'enter_directory', 'play_item', run_action' and
    'toggle_output'.
  * Sorting actions were rebound to Ctrl-S.
  * Support for range selection was added (bound to Ctrl-V by
    default). In addition, sorting, reversing and shuffling
    items in playlist now works on ranges.
  * Support for selecting found items was added (bound to
    Ctrl-_ by default).
  * Tracks in media library are now properly sorted for track
    numbers greater than 99.
  * Value of 'visualizer_sync_interval' is now restricted to
    be greater than 9.
  * Output of the visualizer now scales automatically as long
    as 'visualizer_sample_multiplier' is set to 1.
  * Command line switch that prints current song to the
    standard output is available once again.
  * Defined action chains are now shown in help screen.
  * Action chains for selecting an item and scrolling up/down
    are now bound to Shift-Up and Shift-Down respectively.
  ncmpcpp-0.6.7 (2015-09-12)
  * Fetching artist info from last.fm was fixed.
  ncmpcpp-0.6.6 (2015-09-07)
  * A typo in the example configuration file was fixed.
  * Fetching lyrics from lyricwiki.com was fixed.
  ncmpcpp-0.6.5 (2015-07-05)
  * Description of mouse wheel usage on volume is now correct.
  * Configure script now fails if either readline or pthread
    specific headers are not present.
  * Searching in text fields now respects regular expression
    configuration.
  * When numbering tracks in tag editor all the other track
    tags are discarded.
  * Xiph tag DESCRIPTION is now rewritten as COMMENT when
    updating tags.
  * Possible access of already freed memory when downloading
    artist info is fixed.
  * Name of an item is now displayed correctly if present.
  * Assertion failure when resizing terminal window with no
    active MPD connection is fixed.
  * Lyrics fetchers were updated to work with sites that
    changed their HTML structure.
  ncmpcpp-0.6.4 (2015-05-02)
  * Fix title of a pop-up which shows during adding selected
    items to the current playlist.
  * Correctly deal with leading separator while parsing
    filenames in tag editor.
  * Fix initial incorrect window size that was occuring in
    some cases.
  * Unknown and invalid configuration options can now be
    ignored using command line option 'ignore-config-errors'.
  ncmpcpp-0.6.3 (2015-03-02)
  * Fix floating point exception when adding a specific number
    of random items.
  * Passwords are no longer added to the input history.
  * It is now possible to put more than one specific flag
    consecutively in formats.
  * Bash completion file was removed as it no longer works.
  * Description of available configuration options in man page
    was updated.
  ncmpcpp-0.6.2 (2014-12-13)
  * Delete key now aditionally binds by default to action that
    deletes files in browser.
  * Fix incremental seeking so that it doesn't reset after 30
    seconds.
* Sun Nov 30 2014 fisiu@opensuse.org
- Update to 0.6.1:
  * new features and bugfixes
* Sat May 19 2012 seife+obs@b1-systems.com
- new upstream version 0.5.10
  * builds with gcc 4.7 (Factory)
  * new features, see manpage
* Sat Jan 15 2011 detlef@links2linux.de
- new upstream version <0.5.6>
  * settings: make displaying 'empty tag' entry optional
  * bugfixes
* Thu Aug  5 2010 pascal.bleser@opensuse.org
- update to 0.5.4
- add curl, taglib and fftw support
* Thu Jul 23 2009 detlef@links2linux.de
- new upstream version <0.3.5>
* Sat Nov  1 2008 detlef@links2linux.de
- initial build for PackMan
